#
# spec file for package libdecor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libdecor
Version:        0.2.2
Release:        1.1
Summary:        Wayland client side decoration library
License:        MIT
Group:          System/GUI/Other
URL:            https://gitlab.freedesktop.org/libdecor/libdecor
Source:         %{url}/-/releases/%{version}/downloads/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  gcc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xkbcommon)

%description
A library that can help Wayland clients draw window decorations for them.
It aims to provide multiple backends that implements the decoration drawing.

%package -n libdecor-0-0
Summary:        Library for client-side Wayland decorations
Requires:       %{name}

%description -n libdecor-0-0
A client-side decorations library for Wayland client.

%package        devel
Summary:        Development files for libdecor
Group:          Development/Libraries/C and C++
Requires:       libdecor-0-0 = %{version}

%description    devel
Libraries and header files for developing applications that target libdecor.

%prep
%autosetup

%build
%meson -Ddemo=false
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libdecor-0-0

%files
%license LICENSE
%doc README.md
%{_libdir}/libdecor/

%files -n libdecor-0-0
%{_libdir}/libdecor-0.so.0*

%files devel
%{_includedir}/libdecor-0/
%{_libdir}/libdecor-0.so
%{_libdir}/pkgconfig/libdecor-0.pc

%changelog
* Thu Jul 18 2024 Sean Baggaley <me@drinkybird.net>
- Update to version 0.2.2:
  * gtk: fix memory leak when destroying the gtk plugin
  * gtk: fix memory leak when freeing seats
  * gtk: Make resize corner region larger
  * cairo: Make resize corner region larger
  * cursor-settings: Get theme/size from env if D-Bus call fails
  * gtk: Use g_clear_pointer() in a couple of places
  * gtk: Don't early out of frame free function
  Includes changes from 0.2.1:
  * gtk: Don't report errors during construction
  * Handle NULL wl_output as argument
  * gtk: Optionally use wl_output_release
  * cairo: Optionally use wl_output_release
  * libdecor: fix leak of DBusError in get_setting_sync
  * gtk: use error notification with string formatting
  * gtk: disable setlocale()
  * build: Use `gnu_symbol_visibility` everywhere
* Thu Feb 15 2024 Antonio Larrosa <alarrosa@suse.com>
- Remove the -devel package from baselibs.conf
* Wed Sep 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.2.0:
  * Various bug and leak fixes.
  * New gtk plugin.
- Update URL and source to new home.
- Add pkgconfig(gtk-3.0) BuildRequires, new dependency.
- Use ldconfig_scriptlets macro for post(un) handling.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.1.1:
  * cairo: Keep a ref to the frame while invoking libdecor_frame_close().
  * os-compatibility: handle EINTR gracefully
  * bdecor: drop 'p' prefix for pointer to width and height
  * libdecor: reorder set_min/set_max functions
  * Avoid infinite loop in init_plugins()
  * implement 'frame_get_border_size' for fallback plugin
  * Fix leak of plugin private data
* Thu Apr 14 2022 David Gow <david@davidgow.net>
- Build -32bit packages of libdecor
* Wed Jan 26 2022 Matthias Mailänder <mailaender@opensuse.org>
- initial packaging of version 0.1.0
